Installation
============

1. Setup Python 3.4 or above in a virtual environment::

	# All platforms.
	> python -m venv --system-site-packages pyenv

	# Windows 7/8/10.
	> pyenv/Scripts/activate.bat
	# MacOSX and Linux.
	> source pyenv/bin/activate

3. Install this tool from PIP directly with this short command::

	> pip install nuclai
	
4. Test the script to make sure everything works as expected::

	> nuclai --help

Usage
=====

	> nuclai install <package>
